import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart';
import 'package:reflutter/reflutter.dart';
import 'requests/requests.dart';
import 'responses/responses.dart';

export 'requests/requests.dart';
export 'responses/responses.dart';

part 'catalog.api.dart';

@ReflutterHttp(name: 'SquareCatalog')
abstract class _SquareCatalogEndpoint {
  @Post('/v2/catalog/batch-delete')
  Future<ReflutterResponse<BatchDeleteResponse>> batchDelete(
      @Body() BatchDeleteRequest req);

  @Post('/v2/catalog/batch-retrieve')
  Future<ReflutterResponse<BatchRetrieveResponse>> batchRetrieve(
      @Body() BatchRetrieveRequest body);

  @Post('/v2/catalog/batch-upsert')
  Future<ReflutterResponse<BatchUpsertResponse>> batchUpsert(
      @Body() BatchUpsertRequest body);

  @Get('/v2/catalog/info')
  Future<ReflutterResponse<CatalogInfoResponse>> catalogInfo();

  @Delete('/v2/catalog/object/:objectId')
  Future<ReflutterResponse<DeleteCatalogResponse>> deleteCatalog(
      @Param('object_id') String objectId);

  @Get('/v2/catalog/list')
  Future<ReflutterResponse<ListCatalogResponse>> listCatalog(
      {@QueryParam() String cursor, @QueryParam() String types});

  @Get('/v2/catalog/object/:objectId')
  Future<ReflutterResponse<RetrieveCatalogResponse>> retrieveCatalog(
      @Param('object_id') String objectId,
      {@QueryParam('include_related_objects') bool includeRelatedObjects});

  @Post('/v2/catalog/search')
  Future<ReflutterResponse<SearchCatalogsResponse>> searchCatalogs(
      @Body() SearchCatalogRequest req);

  @Post('/v2/catalog/update-item-modifier-lists')
  Future<ReflutterResponse<UpdateItemResponse>> updateItemModifiers(
      @Body() UpdateItemModifiersRequest req);

  @Post('/v2/catalog/update-item-taxes')
  Future<ReflutterResponse<UpdateItemResponse>> updateItemTaxes(
      @Body() UpdateItemTaxesRequest req);

  @Post('/v2/catalog/object')
  Future<ReflutterResponse<UpsertCatalogResponse>> upsertCatalog(
      @Body() UpsertCatalogRequest req);
}
