import 'package:http/http.dart';
import 'package:reflutter/reflutter.dart';
import 'applepay/applepay.dart';
import 'catalog/catalog.dart';
import 'checkout/checkout.dart';
import 'customers/customers.dart';
import 'inventory/inventory.dart';
import 'locations/locations.dart';
import 'orders/orders.dart';
import 'reporting/reporting.dart';
import 'transactions/transactions.dart';

export 'applepay/applepay.dart';
export 'catalog/catalog.dart';
export 'checkout/checkout.dart';
export 'customers/customers.dart';
export 'inventory/inventory.dart';
export 'locations/locations.dart';
export 'orders/orders.dart';
export 'reporting/reporting.dart';
export 'transactions/transactions.dart';

class ConnectApi {
  static const String _baseUrl = 'https://connect.squareup.com';
  static final Client _client = Client();
  final String _accessToken;

  ConnectApi(String accessToken)
      : _accessToken = accessToken,
        applePay = SquareApplePay(_client, _baseUrl),
        catalog = SquareCatalog(_client, _baseUrl),
        checkout = SquareCheckout(_client, _baseUrl),
        customers = SquareCustomers(_client, _baseUrl),
        inventory = SquareInventory(_client, _baseUrl),
        locations = SquareLocations(_client, _baseUrl),
        orders = SquareOrders(_client, _baseUrl),
        reporting = SquareReporting(_client, _baseUrl),
        transactions = SquareTransactions(_client, _baseUrl) {
    _setupApiDefinition(applePay);
    _setupApiDefinition(catalog);
    _setupApiDefinition(checkout);
    _setupApiDefinition(customers);
    _setupApiDefinition(inventory);
    _setupApiDefinition(locations);
    _setupApiDefinition(orders);
    _setupApiDefinition(reporting);
    _setupApiDefinition(transactions);
  }

  final SquareApplePay applePay;
  final SquareCatalog catalog;
  final SquareCheckout checkout;
  final SquareCustomers customers;
  final SquareInventory inventory;
  final SquareLocations locations;
  final SquareOrders orders;
  final SquareReporting reporting;
  final SquareTransactions transactions;

  void _setupApiDefinition(ReflutterApiDefinition api) {
    api.requestInterceptors.add(_injectHeaders);
  }

  ReflutterRequest<dynamic> _injectHeaders(ReflutterRequest<dynamic> req) {
    req.headers['Authorization'] = 'Bearer $_accessToken';
    req.headers['Accept'] = 'application/json';
    req.headers['Content-Type'] = 'application/json';

    return req;
  }
}
