import 'dart:async';
import 'dart:convert';

import 'package:http/http.dart';
import 'package:reflutter/reflutter.dart';
import 'requests/requests.dart';
import 'responses/responses.dart';

export 'requests/requests.dart';
export 'responses/responses.dart';

part 'customers.api.dart';

@ReflutterHttp(name: 'SquareCustomers')
abstract class _SquareCustomersEndpoint {
  @Post('/v2/customers')
  Future<ReflutterResponse<CreateCustomerResponse>> create(
      @Body() CreateCustomerRequest req);

  @Post('/v2/customers/:customerId/cards')
  Future<ReflutterResponse<CreateCustomerCardResponse>> createCard(
      @Param('customer_id') String customerId,
      @Body() CreateCustomerCardRequest req);

  @Delete('/v2/customers/:customerId')
  Future<ReflutterResponse<DeleteCustomerResponse>> delete(
    @Param('customer_id') String customerId,
  );

  @Delete('/v2/customers/:customerId/cards/:cardId')
  Future<ReflutterResponse<DeleteCustomerCardResponse>> deleteCard(
      @Param('customer_id') String customerId, @Param('card_id') String cardId);

  @Get('/v2/customers')
  Future<ReflutterResponse<ListCustomersResponse>> list(
      @QueryParam() String cursor,
      @QueryParam('sort_field') String sortField,
      @QueryParam('sort_order') String sortOrder);

  @Get('/v2/customers/:customerId')
  Future<ReflutterResponse<RetrieveCustomerResponse>> retrieve(
      @Param('customer_id') String customerId);

  @Post('/v2/customers/search')
  Future<ReflutterResponse<SearchCustomersResponse>> search(
      @Body() SearchCustomersRequest req);

  @Post('/v2/customers/:customerId')
  Future<ReflutterResponse<UpdateCustomerResponse>> update(
      @Param('customer_id') String customerId,
      @Body() UpdateCustomerRequest req);
}
