import 'dart:async';
import 'dart:convert';

import 'package:http/http.dart';
import 'package:reflutter/reflutter.dart';
import 'requests/requests.dart';
import 'responses/responses.dart';

export 'requests/requests.dart';
export 'responses/responses.dart';

part 'inventory.api.dart';

@ReflutterHttp(name: 'SquareInventory')
abstract class _SquareInventoryEndpoint {
  @Post('/v2/inventory/batch-change')
  Future<ReflutterResponse<BatchChangeInventoryResponse>> batchChange(
      @Body() BatchChangeInventoryRequest req);

  @Post('/v2/inventory/batch-retrieve-changes')
  Future<ReflutterResponse<BatchRetrieveChangesResponse>> batchRetrieveChanges(
      @Body() BatchRetrieveChangesRequest req);

  @Post('/v2/inventory/batch-retrieve-counts')
  Future<ReflutterResponse<BatchRetrieveCountsResponse>> batchRetrieveCounts(
      @Body() BatchRetrieveCountsRequest req);

  @Get('/v2/inventory/adjustment/:adjustmentId')
  Future<ReflutterResponse<RetrieveAdjustmentsResponse>>
      retrieveInventoryAdjustment(@Param('adjustment_id') String adjustmentId);

  @Get('/v2/inventory/:catalogObjectId/changes')
  Future<ReflutterResponse<RetrieveChangesResponse>> retrieveChanges(
      @Param('catalog_object_id') String catalogObjectId,
      @QueryParam('location_ids') String locationIds,
      @QueryParam() String cursor);

  @Get('/v2/inventory/:catalogObjectId')
  Future<ReflutterResponse<RetrieveCountResponse>> retrieveCount(
      @Param('catalog_object_id') String catalogObjectId,
      @QueryParam('location_ids') String locationIds,
      @QueryParam() String cursor);

  @Get('/v2/inventory/physical-count/:physicalCountId')
  Future<ReflutterResponse<RetrievePhysicalCountResponse>>
      retrievePhysicalCount(@Param('physical_count_id') String physicalCountId);
}
